@@ -22,10 +22,10 @@ impl Kernel {
 	 * @param  ArgMatches
 	 * @return Kernel
 	 */
-	pub fn new(args: &ArgMatches<'_>) -> Self {
+	pub fn new(args: &ArgMatches) -> Self {
 		Self {
 			logs: KernelLogs::default(),
-			info: KernelInfo::new(),
+			info: KernelInfo::default(),
 			modules: KernelModules::new(ListArgs::new(args), Style::new(args)),
 		}
 	}
@@ -34,6 +34,6 @@ impl Kernel {
 	pub fn refresh(&mut self) {
 		self.logs.refresh();
 		self.info.refresh();
-		self.modules.refresh();
+		let _ = self.modules.refresh();
 	}
 }
