@@ -1,8 +1,8 @@
 use clap::ArgMatches;
 use colorsys::Rgb;
+use ratatui::style::{Color, Modifier, Style as TuiStyle};
+use ratatui::text::{Line, Span, Text};
 use std::collections::HashMap;
-use tui::style::{Color, Modifier, Style as TuiStyle};
-use tui::text::{Span, Spans, Text};
 
 /* Unicode symbol */
 #[derive(Clone, Copy, Debug, Eq, PartialEq, Hash)]
@@ -87,9 +87,9 @@ impl Style {
 	 * @param  args
 	 * @return Style
 	 */
-	pub fn new(args: &ArgMatches<'_>) -> Self {
+	pub fn new(args: &ArgMatches) -> Self {
 		let mut default = TuiStyle::reset();
-		if args.is_present("accent-color") {
+		if let Ok(true) = args.try_contains_id("accent-color") {
 			default =
 				default.fg(Self::get_color(args, "accent-color", Color::White));
 		}
@@ -101,7 +101,9 @@ impl Style {
 				"color",
 				Color::DarkGray,
 			)),
-			unicode: Unicode::new(!args.is_present("unicode")),
+			unicode: Unicode::new(
+				args.try_get_one::<bool>("unicode").ok().flatten() == Some(&false),
+			),
 		}
 	}
 
@@ -113,11 +115,7 @@ impl Style {
 	 * @param  default_color
 	 * @return Color
 	 */
-	fn get_color(
-		args: &ArgMatches<'_>,
-		arg_name: &str,
-		default_color: Color,
-	) -> Color {
+	fn get_color(args: &ArgMatches, arg_name: &str, default_color: Color) -> Color {
 		let colors = map![
 			"black" => Color::Black,
 			"red" => Color::Red,
@@ -136,9 +134,9 @@ impl Style {
 			"lightcyan" => Color::LightCyan,
 			"white" => Color::White
 		];
-		match args.value_of(arg_name) {
-			Some(v) => *colors.get::<str>(&v.to_lowercase()).unwrap_or({
-				if let Ok(rgb) = Rgb::from_hex_str(&format!("#{}", v)) {
+		match args.try_get_one::<String>(arg_name) {
+			Ok(Some(v)) => *colors.get::<str>(&v.to_lowercase()).unwrap_or({
+				if let Ok(rgb) = Rgb::from_hex_str(&format!("#{v}")) {
 					Box::leak(Box::new(Color::Rgb(
 						rgb.red() as u8,
 						rgb.green() as u8,
@@ -148,7 +146,7 @@ impl Style {
 					&default_color
 				}
 			}),
-			None => default_color,
+			_ => default_color,
 		}
 	}
 }
@@ -204,14 +202,14 @@ impl<'a> StyledText<'a> {
 		for line in text.lines() {
 			let data = line.split(delimiter).collect::<Vec<&str>>();
 			if data.len() > 1 && data[0].trim().len() > 2 {
-				self.styled_text.lines.push(Spans::from(vec![
+				self.styled_text.lines.push(Line::from(vec![
 					Span::styled(format!("{}{}", data[0], delimiter), style.colored),
 					Span::styled(data[1..data.len()].join(delimiter), style.default),
 				]));
 			} else {
 				self.styled_text
 					.lines
-					.push(Spans::from(Span::styled(line, style.default)))
+					.push(Line::from(Span::styled(line, style.default)))
 			}
 		}
 		self.styled_text.clone()
@@ -256,7 +254,7 @@ mod tests {
 		let mut unicode = Unicode::new(true);
 		for symbol in unicode.symbols.clone() {
 			if symbol.0 != Symbol::Blank {
-				assert_eq!(true, symbol.1[1].len() < 2)
+				assert!(symbol.1[1].len() < 2)
 			}
 		}
 		unicode.replace = false;
